/** @description 获取当前的环境变量名称 是否是正式环境
 * */
export const isProduction = () => {
	return ['yibin', 'zigong'].includes(import.meta.env.VITE_MODE_NAME);
};
/**
 * @description 获取当前市州配置
 * @returns {object}
 * @example {
 *     cityName: 'name', // 中文名称
 *     cityCode: 'code', // 6位区号
 *     cityAbbr: 'abbr', // 简写
 *     recordNumber: 'recordNumber', // 备案号
 *     locationCenter: [lat,lng], // 地图中心点
 *     loginBg: 'loginBg', // 登录背景
 *     isShowLogo: true, // 是否显示左上角logo
 *     callCenterSocketUrl: 'ws://218.6.151.146:50104/ola_socket', // 呼叫中心socket地址
 *     recordPrefix: 'http://192.168.2.212:29003', // 播放录音地址前缀
 *     recordDownLoadPrefix: 'http://192.168.2.212:29003', // 录音地址下载前缀
 * }
 */
export const getCurrentCityConfig = () => {
	switch (import.meta.env.VITE_CURRENT_CITY) {
		case 'yibin':
			return {
				cityName: '宜宾市', // 中文名称
				cityCode: '511500', // 6位区号
				operate: '中国电信股份有限公司宜宾分公司',
				techSupport: '成都丰窝科技有限公司',
				cityAbbr: '宜宾', // 简写
				recordNumber: '蜀ICP备19035032号-36', // 备案号
				locationCenter: [104.643, 28.751694], // 地图中心点
				loginBg: 'yibin/login_bg.png', // 登录背景
				isShowLogo: true, // 是否显示菜单左上角logo
				favicon: 'yibin/favicon.ico',
				callCenterSocketUrl: isProduction() ? 'ws://218.6.151.146:50104/ola_socket' : ' ws://222.213.23.229:29003/ola_socket', // 呼叫中心socket地址
				recordPrefix: isProduction() ? 'http://218.6.151.146:50104' : 'http://222.213.23.229:10085', // 播放录音地址前缀
				recordDownLoadPrefix: isProduction() ? 'http://192.168.2.212:29003' : 'http://222.213.23.229:10085', // 录音地址下载前缀
			};
		case 'zigong':
			return {
				cityName: '自贡市',
				cityCode: '510300',
				operate: '中国电信股份有限公司自贡分公司',
				techSupport: '成都丰窝科技有限公司',
				cityAbbr: 'zg',
				recordNumber: '蜀ICP备2024053169号-1',
				locationCenter: [104.778001, 29.339399],
				// loginBg: 'zigong/login_bg.png',
				loginBg: 'login/login_bg.png',
				isShowLogo: false,
				favicon: 'zigong/favicon.ico',
				callCenterSocketUrl: isProduction() ? 'ws://123.56.10.71:7681' : ' ws://123.56.10.71:7681', // 呼叫中心socket地址
				recordPrefix: isProduction() ? 'http://123.56.10.71:8066/' : 'http://123.56.10.71:8066/', // 播放录音地址前缀
				recordDownLoadPrefix: isProduction() ? 'http://123.56.10.71:8066/' : 'http://123.56.10.71:8066/', // 录音地址下载前缀
			};
		default:
			return {
				cityName: '宜宾市', // 中文名称
				cityCode: '511500', // 6位区号
				operate: '中国电信股份有限公司宜宾分公司',
				techSupport: '成都丰窝科技有限公司',
				cityAbbr: '宜宾', // 简写
				recordNumber: '蜀ICP备19035032号-36', // 备案号
				locationCenter: [104.643, 28.751694], // 地图中心点
				loginBg: 'yibin/login_bg.png', // 登录背景
				isShowLogo: true, // 是否显示左上角logo
				favicon: 'yibin/favicon.ico',
				callCenterSocketUrl: isProduction() ? 'ws://218.6.151.146:50104/ola_socket' : ' ws://222.213.23.229:29003/ola_socket', // 呼叫中心socket地址
				recordPrefix: isProduction() ? 'http://218.6.151.146:50104' : 'http://222.213.23.229:10085', // 播放录音地址前缀
				recordDownLoadPrefix: isProduction() ? 'http://192.168.2.212:29003' : 'http://222.213.23.229:10085', // 录音地址下载前
			};
	}
};
